@@ -118,8 +118,12 @@ class RangerAdaBelief(Optimizer):
             for p in group['params']:
                 if p.grad is None:
                     continue
+
                 grad = p.grad.data.float()
 
+                if not self.weight_decouple: # if not decoupled weight decay, add weight decay to grad
+                    grad.add_(p.data * group['weight_decay'])
+
                 if grad.is_sparse:
                     raise RuntimeError(
                         'Ranger optimizer does not support sparse gradients')
@@ -199,18 +203,14 @@ class RangerAdaBelief(Optimizer):
                 else:
                     G_grad = exp_avg
 
-                if (not self.weight_decouple) and (group['weight_decay'] != 0):
+                if self.weight_decouple and (group['weight_decay'] != 0): # decoupled weight decay
                     G_grad.add_(p_data_fp32, alpha=group['weight_decay'])
 
                 # GC operation
                 if self.gc_loc == False:
                     G_grad = centralized_gradient(G_grad, use_gc=self.use_gc, gc_conv_only=self.gc_conv_only)
 
-                if not self.weight_decouple:
-                    p_data_fp32.add_(G_grad, alpha=-step_size * group['lr'])
-                else:
-                    # decoupled weight decat
-                    p_data_fp32.mul_( 1.0 - group['lr'] * group['weight_decay'] )
+                p_data_fp32.add_(G_grad, alpha=-step_size * group['lr'])
 
                 p.data.copy_(p_data_fp32)
 
